#
#  This code is based on an example on the rrdtool ruby site - http://oss.oetiker.ch/rrdtool/prog/rrdruby.en.html
#  This code  tests the following rrdtool functions. 
#   create, update, graph, dump, restore, fetch, first, last and info
#
#   Author: Barrie Hill <barrie0482@gmail.com>
#   Date: 11/7/2009
#
require 'RRD'
Dir.chdir('../'){ENV["RRD_DEFAULT_FONT"] = (PATH = Dir.pwd) + '/resources/DejaVuSansMono-Roman.ttf'}
name = "test"
rrdpath = '..'
rrddir = "#{rrdpath}"
rrd = "#{name}.rrd"
xml = "#{name}.xml"
start = Time.now.to_i
rrdend = start + 1000*60
png = "#{name}.png"

#
# Test rrdtool create
#
puts 
puts "Test rrdtool create"
puts
puts "Creating a RRD called #{rrddir}/#{rrd} starting at #{start - 1} unix time (#{Time.at(start -1)} local time)."
puts "........ finishing at #{rrdend} unix time (#{Time.at(rrdend)} local time)."
RRD.create(    
  "#{rrddir}/#{rrd}",
  "--start", "#{start - 1}",
  "--step", "300",
  "DS:a:GAUGE:600:U:U",
  "DS:b:GAUGE:600:U:U",
  "RRA:AVERAGE:0.5:1:300")
#
# Test rrdtool update
#
puts 
puts "Test rrdtool update"
puts "........ updating #{rrd}"
start.to_i.step(start.to_i + 300 * 300, 300) { |i|
  RRD.update("#{rrddir}/#{rrd}", "#{i}:#{rand(100)}:#{Math.sin(i / 800) * 50 + 50}")
}
puts
#
# Test rrdtool graph
#
puts 
puts "Test rrdtool graph"
puts "........ generating graph #{rrddir}/#{png}"

   RRD.graph(
  "#{rrddir}/#{png}",
  "--title", "RRDWrapper Demo",
  "--start", "#{start+3600}",
  "--end", "#{rrdend}",
  "--interlace", 
  "--imgformat", "PNG",
  "--width=450",
  "DEF:a=#{rrddir}/#{rrd}:a:AVERAGE",
  "DEF:b=#{rrddir}/#{rrd}:b:AVERAGE",
  "CDEF:line=TIME,2400,%,300,LT,a,UNKN,IF",
  "AREA:b#00b6e4:beta",
  "AREA:line#0022e9:alpha",
  "LINE3:line#ff0000")
  
puts
#
# Test rrdtool dump - write rrd to xml file
#
puts 
puts "Test rrdtool dump"
puts "........ dumping rrd file to #{rrddir}/#{xml}"
RRD.dump("#{rrddir}/#{rrd}","#{rrddir}/#{xml}")
#
#
#
name = "restored"
newrrd = "#{name}.rrd"
newpng = "#{name}.png"
#
# Test rrdtool restore - write xml to rrd file
#
puts 
puts "Test rrdtool restore"
puts "........ restoring rrd file to #{rrddir}/#{newrrd}"
RRD.restore("#{rrddir}/#{xml}", "#{rrddir}/#{newrrd}")
puts
#
# Test rrdtool graph
#
puts 
puts "Test rrdtool graph from restored rrd file"
puts "........ generating graph #{rrddir}/#{newpng}"
RRD.graph(
  "#{rrddir}/#{newpng}",
  "--title", "RRDWrapper Restore Demo",
  "--start", "#{start+3600}",
  "--end", "#{rrdend}",
  "--interlace", 
  "--imgformat", "PNG",
  "--width=450",
  "DEF:a=#{rrddir}/#{newrrd}:a:AVERAGE",
  "DEF:b=#{rrddir}/#{newrrd}:b:AVERAGE",
  "CDEF:line=TIME,2400,%,300,LT,a,UNKN,IF",
  "AREA:b#00b6e4:beta",
  "AREA:line#0022e9:alpha",
  "LINE3:line#ff0000")
  
puts
#
# Test rrdtool fetch
#
puts 
puts "Test rrdtool fetch"
puts "........ fetching data from #{rrd}"
data = RRD.fetch("#{rrddir}/#{rrd}", "AVERAGE", "--start", start.to_s, "--end",(start + 1000).to_s)
puts "got #{data.length} data points"  
p data
puts
puts "Test rrdtool first"
puts "........ rrdtool first - returns the date of the first data sample in #{rrd}"
first = RRD.first("#{rrddir}/#{rrd}")
puts "The first value in #{rrddir}/#{rrd} was entered #{first.to_i} unix time (#{Time.at(first.to_i)} local time)"
puts "........ rrdtool first - returns the date of the first data sample in #{newrrd}"
first = RRD.first("#{rrddir}/#{newrrd}")
puts "The first value in #{rrddir}/#{newrrd} was entered #{first.to_i} unix time (#{Time.at(first.to_i)} local time)"
#
# Test rrdtool last
#
puts 
puts "Test rrdtool last"
puts "........ rrdtool last - returns the date of the last data sample in #{rrd}"
last = RRD.last("#{rrddir}/#{rrd}")
puts "The last value in #{rrddir}/#{rrd} was entered #{last.to_i} unix time (#{Time.at(last.to_i)} local time)"
puts "........ rrdtool last - returns the date of the last data sample in #{newrrd}"
last = RRD.last("#{rrddir}/#{newrrd}")
puts "The last value in #{rrddir}/#{newrrd} was entered #{last.to_i} unix time (#{Time.at(last.to_i)} local time)"
#
# Test rrdtool info
#
puts 
puts "Test rrdtool info"
puts "........ rrdtool info - extract header information from #{rrd}"
info = RRD.info("#{rrddir}/#{rrd}")
p info
puts
puts "Your test files are located in #{rrddir}"
puts "Delete or move them before you run this program again"
